@@ -52,14 +52,23 @@ def reverseScore(Score, matchScore:float):
     Score =matchScore-(Score**0.5)
     return Score
 
-def QuantitativeScoreFile(ScoreFile, matchScore = -999.):
+def QuantitativeScoreFile(lllleaf, llllleaf, mav:float, miv:float, ScoreFile, matchScore = -999.):
     score_dict={}
+    for i in itertools.product(set(lllleaf), set(llllleaf)):
+        score_dict[i[0].nodeobj+'_'+i[1].nodeobj] = float(miv)
+    for i in lllleaf:
+        score_dict[i.nodeobj+'_'+i.nodeobj] = float(mav)
+    for i in llllleaf:
+        score_dict[i.nodeobj+'_'+i.nodeobj] = float(mav)
     typeXn_dict = {}
-    csv_reader=csv.reader(open(ScoreFile,encoding='utf-8'))
-    for row in islice(csv_reader, 1, None): #跳过第一行名称信息
+    csv_reader=csv.reader(open(ScoreFile,'r', encoding="ISO-8859-1"))
+    #for row in islice(csv_reader, 1, None): #跳过第一行名称信息
+    for row in csv_reader:
         #print(row)
         if len(row) == 3:
-            score_dict[row[0]+ '_' + row[1]] = row[2]
+            if isNum(row[2]):
+                score_dict[row[0]+ '_' + row[1]] = float(row[2])
+                score_dict[row[1]+ '_' + row[0]] = float(row[2])
         else:
             typeXn_dict[row[0]]=row[1:]
         #print(list(typeXn_dict.keys()))
